@@ -1,4 +1,12 @@
+"""
+.. testsetup::
+
+    from compas.geometry import Frame
+
+"""
 from __future__ import print_function
+from __future__ import absolute_import
+from __future__ import division
 
 from compas.geometry import allclose
 from compas.geometry import argmax
@@ -730,13 +738,3 @@ class Frame(Primitive):
         self.point = point
         self.xaxis = xaxis
         self.yaxis = yaxis
-
-
-# ==============================================================================
-# Main
-# ==============================================================================
-
-if __name__ == '__main__':
-
-    import doctest
-    doctest.testmod(globs=globals())
